/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var app = {
    // Application Constructor
	autoShowInterstitial: true,
  progressDialog: document.getElementById("progressDialog"),
  spinner: document.getElementById("spinner"),
  weinre: {
    enabled: false,
    ip: '', // ex. http://192.168.1.13
    port: '', // ex. 9090
    targetApp: '' // ex. see weinre docs
  },		
    initialize: function() {	
	if (( /(ipad|iphone|ipod|android)/i.test(navigator.userAgent) )) {
      document.addEventListener('deviceready', this.onDeviceReady, false);
    } else {
      app.onDeviceReady();
    }
	this.bindEvents();		
    },
	
	initAds: function () {
    var isAndroid = (/(android)/i.test(navigator.userAgent));
    var adPublisherIds = {
       ios: {
                banner: 'ca-app-pub-9863325511078756/5232547029',
                interstitial: 'ca-app-pub-9863325511078756/6709280228'
            },
            android: {
                banner: 'ca-app-pub-4552522230061043/8076930411',
                interstitial: 'ca-app-pub-4552522230061043/9553663614'
            }
    };

    var admobid;
    if (isAndroid) {
      admobid = adPublisherIds.android;
    } else {
      admobid = adPublisherIds.ios;
    }

    admob.setOptions({
      publisherId: admobid.banner,
      interstitialAdId: admobid.interstitial,
      bannerAtTop: false, // set to true, to put banner at top
      overlap: false, // set to true, to allow banner overlap webview
      offsetStatusBar: true, // set to true to avoid ios7 status bar overlap
      isTesting: false, // receiving test ads (do not test with real ads as your account will be banned)
      autoShowBanner: true, // auto show banners ad when loaded
      autoShowInterstitial: true // auto show interstitials ad when loaded
    });
    
    // Adjust viewport
    var viewportScale = 1 / window.devicePixelRatio;
    document.getElementById("viewport").setAttribute("content", "user-scalable=no, initial-scale=" + viewportScale + ", minimum-scale=0.2, maximum-scale=2, width=device-width"); 
  },
  
  // Bind Event Listeners
	bindAdEvents: function () {
    document.addEventListener("orientationchange", this.onOrientationChange, false);
    document.addEventListener(admob.events.onAdLoaded, this.onAdLoaded, false);
    document.addEventListener(admob.events.onAdFailedToLoad, this.onAdFailedToLoad, false);
    document.addEventListener(admob.events.onAdOpened, function (e) {}, false);
    document.addEventListener(admob.events.onAdClosed, function (e) {}, false);
    document.addEventListener(admob.events.onAdLeftApplication, function (e) {}, false);
    document.addEventListener(admob.events.onInAppPurchaseRequested, function (e) {}, false);
  },
  
  onOrientationChange: function () {
    app.onResize();
  },
  
    // Bind Event Listeners
    //
    // Bind any events that are required on startup. Common events are:
    // 'load', 'deviceready', 'offline', and 'online'.
    bindEvents: function() {
        document.addEventListener('deviceready', this.onDeviceReady, false);
    },
    // deviceready Event Handler
    //
    // The scope of 'this' is the event. In order to call the 'receivedEvent'
    // function, we must explicitly call 'app.receivedEvent(...);'
    onDeviceReady: function() {
	var weinre,
        weinreUrl;
    
    document.removeEventListener('deviceready', app.onDeviceReady, false);
    
    if (app.weinre.enabled) {
      console.log('Loading weinre...');
      weinre = document.createElement('script');
      weinreUrl = app.weinre.ip + ":" + app.weinre.port;
      weinreUrl += '/target/target-script-min.js';
      weinreUrl += '#' + app.weinre.targetApp;
      weinre.setAttribute('src', weinreUrl);
      document.head.appendChild(weinre);
    }
    
    if (admob) {
      console.log('Binding ad events...');
      app.bindAdEvents();
      console.log('Initializing ads...');
      app.initAds();
    } else {
      alert('AdMobAds plugin not ready');
    }
        app.receivedEvent('deviceready');
        app.fnStartClock();		
        
    },
	
	onAdLoaded: function (e) {
    app.showProgress(false);
    if (e.adType === admob.AD_TYPE.INTERSTITIAL) {
      if (app.autoShowInterstitial) {
        admob.showInterstitialAd();
      } else {
        alert("Interstitial is available. Click on 'Show Interstitial' to show it.");
      }
    }
  },
  onAdFailedToLoad: function(event, e) {
    app.showProgress(false);
    alert("Could not load ad: " + e.reason);
  },
  onResize: function () {
    var msg = 'Web view size: ' + window.innerWidth + ' x ' + window.innerHeight;
    document.getElementById('sizeinfo').innerHTML = msg;
  },
  
  startBannerAds: function () {
      admob.createBannerView(function (){}, function (e) {
      alert(JSON.stringify(e));
    });
  },
  removeBannerAds: function () {
    app.showProgress(false);
    admob.destroyBannerView();
  },
  showBannerAds: function () {
    app.showProgress(false);
    admob.showBannerAd(true, function (){}, function (e) {
      alert(JSON.stringify(e));
    });
  },
  hideBannerAds: function () {
    app.showProgress(false);
    admob.showBannerAd(false);
  },
  requestInterstitial: function (autoshow) {
    app.autoShowInterstitial = autoshow;
    admob.requestInterstitialAd(function (){}, function (e) {
      alert(JSON.stringify(e));
    });
  },
  showInterstitial: function() {
    app.showProgress(false);
    admob.showInterstitialAd(function (){}, function (e) {
      alert(JSON.stringify(e));
    });
  },
  showProgress: function(show) {
    if (show) {
      addClass(app.spinner, "animated");
      removeClass(app.progressDialog, "hidden");
    } else {
      addClass(app.progressDialog, "hidden");
      removeClass(app.spinner, "animated");
    }
  },
  
  fnStartClock: function() {

            try {
                oInterval = setInterval("app.requestInterstitial(true)", 3000);
            }
            catch (e) {
                alert("fnStartClock" + e);
            }
        },
  
    // Update DOM on a Received Event
    receivedEvent: function(id) {
        var parentElement = document.getElementById(id);
        var listeningElement = parentElement.querySelector('.listening');
        var receivedElement = parentElement.querySelector('.received');

        listeningElement.setAttribute('style', 'display:none;');
        receivedElement.setAttribute('style', 'display:block;');

        console.log('Received Event: ' + id);
    }	
};


function removeClass(elem, cls) {
  var str;
  do {
    str = " " + elem.className + " ";
    elem.className = str.replace(" " + cls + " ", " ").replace(/^\s+|\s+$/g, "");
  } while (str.match(cls));
}

function addClass(elem, cls) {
  elem.className += (" " + cls);
}
